@@ -1,5 +1,5 @@
 import functools
-import json as _json
+from engineio import json as _json
 
 (CONNECT, DISCONNECT, EVENT, ACK, CONNECT_ERROR, BINARY_EVENT, BINARY_ACK) = \
     (0, 1, 2, 3, 4, 5, 6)
@@ -15,8 +15,7 @@ class Packet(object):
     # packet type: 1 byte, values 0-6
     # num_attachments: ASCII encoded, only if num_attachments != 0
     # '-': only if num_attachments != 0
-    # namespace: only if namespace != '/'
-    # ',': only if namespace and one of id and data are defined in this packet
+    # namespace, followed by a ',': only if namespace != '/'
     # id: ASCII encoded, only if id is not None
     # data: JSON dump of data payload
 
@@ -54,18 +53,11 @@ class Packet(object):
         else:
             data = self.data
             attachments = None
-        needs_comma = False
         if self.namespace is not None and self.namespace != '/':
-            encoded_packet += self.namespace
-            needs_comma = True
+            encoded_packet += self.namespace + ','
         if self.id is not None:
-            if needs_comma:
-                encoded_packet += ','
-                needs_comma = False
             encoded_packet += str(self.id)
         if data is not None:
-            if needs_comma:
-                encoded_packet += ','
             encoded_packet += self.json.dumps(data, separators=(',', ':'))
         if attachments is not None:
             encoded_packet = [encoded_packet] + attachments
@@ -87,6 +79,8 @@ class Packet(object):
         self.data = None
         ep = ep[1:]
         dash = ep.find('-')
+        if dash > 10:
+            raise ValueError('too many attachments')
         attachment_count = 0
         if dash > 0 and ep[0:dash].isdigit():
             attachment_count = int(ep[0:dash])
@@ -103,10 +97,16 @@ class Packet(object):
             if q != -1:
                 self.namespace = self.namespace[0:q]
         if ep and ep[0].isdigit():
-            self.id = 0
-            while ep and ep[0].isdigit():
-                self.id = self.id * 10 + int(ep[0])
-                ep = ep[1:]
+            i = 1
+            end = len(ep)
+            while i < end:
+                if not ep[i].isdigit() or i >= 100:
+                    break
+                i += 1
+            self.id = int(ep[:i])
+            ep = ep[i:]
+            if len(ep) > 0 and ep[0].isdigit():
+                raise ValueError('id field is too long')
         if ep:
             self.data = self.json.loads(ep)
         return attachment_count
